@@ -62,7 +62,7 @@ def sheed_id2excel(service, sheet_id, excel_file):
 
 
 
-def excel2dict(sheet, interaktion_spalte, poi_spalte, aktion_spalte, format_spalte, inhalt_spalte, max_row):
+def excel2dict(sheet, interaktion_spalte, poi_spalte, aktion_spalte, format_spalte, inhalt_spalte, max_row=None):
 
     excel_dict = defaultdict(
         lambda: defaultdict(
@@ -74,34 +74,36 @@ def excel2dict(sheet, interaktion_spalte, poi_spalte, aktion_spalte, format_spal
     previous_aktion=""
 
     for row in sheet.iter_rows(min_row=2, max_row=max_row):
-        if row[interaktion_spalte].value == None:
-            interaktion = previous_interaktion
-        else:
-            interaktion = row[interaktion_spalte].value
-            previous_interaktion = interaktion
+        if row[interaktion_spalte] or row[poi_spalte] or row[aktion_spalte] or row[format_spalte] or row[inhalt_spalte]:
 
-        if row[poi_spalte].value == None:
-            poi = previous_pio
-        else:
-            poi = row[poi_spalte].value
-            previous_pio = poi
+            if row[interaktion_spalte].value == None:
+                interaktion = previous_interaktion
+            else:
+                interaktion = row[interaktion_spalte].value
+                previous_interaktion = interaktion
 
-        if row[aktion_spalte].value == None:
-            aktion = previous_aktion
-        else:
-            aktion = row[aktion_spalte].value
-            previous_aktion = aktion
+            if row[poi_spalte].value == None:
+                poi = previous_pio
+            else:
+                poi = row[poi_spalte].value
+                previous_pio = poi
 
-        if row[format_spalte].value == None:
-            ValueError("Empty Field in {}".format(row[format_spalte]))
-        else:
-            format = row[format_spalte].value
+            if row[aktion_spalte].value == None:
+                aktion = previous_aktion
+            else:
+                aktion = row[aktion_spalte].value
+                previous_aktion = aktion
 
-        if row[inhalt_spalte].value == None:
-            ValueError("Empty Field in {}".format(row[inhalt_spalte]))
-        else:
-            inhalt = row[inhalt_spalte].value
+            if row[format_spalte].value == None:
+                ValueError("Empty Field in {}".format(row[format_spalte]))
+            else:
+                format = row[format_spalte].value
 
-        excel_dict[(poi, interaktion)][aktion].append((format, inhalt))
+            if row[inhalt_spalte].value == None:
+                ValueError("Empty Field in {}".format(row[inhalt_spalte]))
+            else:
+                inhalt = row[inhalt_spalte].value
+
+            excel_dict[(poi, interaktion)][aktion].append((format, inhalt))
     
     return excel_dict
\ No newline at end of file
