@@ -4,7 +4,7 @@ from telegram.ext import (CallbackContext)
 
 from digitalguide.whatsapp.WhatsAppUpdate import WhatsAppUpdate
 
-def telegram_loop_list(update: Update, context: CallbackContext, key, value, doppelte_antwort, answer_id_list, fertig_antwort):
+def telegram_loop_list(update: Update, context: CallbackContext, key, value, doppelte_antwort):
     if not key in context.user_data:
         context.user_data[key] = []
 
@@ -15,7 +15,8 @@ def telegram_loop_list(update: Update, context: CallbackContext, key, value, dop
     else:
         context.user_data[key].append(value)
 
-    if set(answer_id_list) == set(context.user_data[key]):
+def telegram_loop_list_fertig(update: Update, context: CallbackContext, key, answer_id_list, fertig_antwort):
+    if set(answer_id_list).issubset(set(context.user_data[key])):
         update.message.reply_text(fertig_antwort,
                                     reply_markup=ReplyKeyboardRemove())
 
@@ -34,7 +35,7 @@ def whatsapp_loop_list(client, update: WhatsAppUpdate, context,  key, value, dop
     else:
         context[key].append(value)
 
-    if set(answer_id_list) == set(context.user_data[key]):
+    if set(answer_id_list).issubset(set(context.user_data[key])):
         client.messages.create(
             body=fertig_antwort,
             from_=update.To,
@@ -78,7 +79,8 @@ def whatsapp_eval_list(client, update: WhatsAppUpdate, context, answer_id_name_l
 
 
 telegram_action_functions = {"loop_list": telegram_loop_list,
-                             "eval_list": telegram_eval_list
+                             "eval_list": telegram_eval_list,
+                             "loop_list_fertig": telegram_loop_list_fertig
                              }
 
 whatsapp_action_functions = {"loop_list": whatsapp_loop_list,
