@@ -69,19 +69,20 @@ def readActions(format_inhalt_list, messanger="Telegram", asset_url=""):
                 action["caption"] = inhalt
 
         elif format == "Foto":
-            action["type"] = "photo"
-            regex = r"Datei: (?P<file>.*)\nAnzeigename: (?P<name>.*)"
+            action["type"] = "photo"            
+            file_match = re.search(r"Datei: (?P<file>.*)", inhalt)
 
-            match = re.search(regex, inhalt)
-            if match:
-                action["url"] = os.path.join(asset_url, match.group('file'))
+            if file_match:
+                action["url"] = os.path.join(asset_url, file_match.group('file'))
                 if requests.get(action["url"]).status_code != 200:
                     print("Die angegebene Datei ({}) konnte nicht unter der Asset URL ({}) gefunden werden.".format(
-                    match.group('file'), asset_url))
-                action["caption"] = match.group('name')
+                    file_match.group('file'), asset_url))
             else:
                 action["url"] = os.path.join(asset_url, "platzhalter.png")
-                action["caption"] = inhalt
+
+            caption_match = re.search(r"Anzeigename: (?P<name>.*)", inhalt)
+            if caption_match:
+                action["caption"] = caption_match.group('name')
 
         elif format == "GIF":
             action["type"] = "document"
