@@ -25,10 +25,13 @@ class Action():
 
     def __call__(self, client, update: WhatsAppUpdate, context):
         for item in self.actions:
-            
+            if item["type"] == "return":
+                return item["state"]
+
             wait_itteration = 0
             max_wait_itteration = 50
             while unsend_messages[update.From] and wait_itteration <= max_wait_itteration:
+                print(unsend_messages, wait_itteration)
                 time.sleep(.1)
                 wait_itteration+=1
 
@@ -44,52 +47,55 @@ class Action():
                 print("after add",unsend_messages)
                 print(message.sid)
             elif item["type"] == "venue":
-                client.messages.create(
+                message = client.messages.create(
                     body=item["title"],
                     persistent_action=['geo:{},{}|{}'.format(
                         item["latitude"], item["longitude"], item["address"])],
                     from_=update.To,
                     to=update.From
                 )
+                unsend_messages[update.From].add(message.sid)
             elif item["type"] == "photo":
-                client.messages.create(
+                message = client.messages.create(
                     media_url=item["url"],
                     from_=update.To,
                     to=update.From
                 )
+                unsend_messages[update.From].add(message.sid)
             elif item["type"] == "video":
-                client.messages.create(
+                message = client.messages.create(
                     media_url=item["url"],
                     from_=update.To,
                     to=update.From
                 )
+                unsend_messages[update.From].add(message.sid)
             elif item["type"] == "media_group":
-                client.messages.create(
+                message = client.messages.create(
                     media_url=item["urls"],
                     from_=update.To,
                     to=update.From
                 )
+                unsend_messages[update.From].add(message.sid)
             elif item["type"] == "audio" or item["type"] == "voice":
-                client.messages.create(
+                message = client.messages.create(
                     media_url=[item["url"]],
                     from_=update.To,
                     to=update.From
                 )
+                unsend_messages[update.From].add(message.sid)
             elif item["type"] == "poll":
                 message = item["question"] + "\n"
                 for option in item["options"]:
                     message += option + "\n"
-                client.messages.create(
+                message = client.messages.create(
                     body=message,
                     from_=update.To,
                     to=update.From
                 )
+                unsend_messages[update.From].add(message.sid)
 
             elif item["type"] == "function":
                 arguments = {i: item[i]
                              for i in item if i != 'type' and i != 'func'}
                 self.action_functions[item["func"]](
-                    client, update, context, **arguments)
-
-            elif item["type"] == "return":
-                return item["state"]
+                    client, update, context, **arguments)
\ No newline at end of file
